===========================
Deploying Dask using MPI4Py
===========================

|Gitter| |Circle| |Codecov| |Docs| |PyPI| |Conda|

Easily deploy Dask Distributed in an existing MPI environment, such as one
created with the ``mpirun`` or ``mpiexec`` MPI launch commands.  See documentation_
for more details.


LICENSE
-------

BSD 3-Clause (See `License File <https://github.com/dask/dask-mpi/blob/master/LICENSE.txt>`__)

.. _documentation: http://mpi.dask.org

.. |Gitter| image:: https://img.shields.io/gitter/room/dask/dask.svg?style=for-the-badge
   :alt: Join the chat at https://gitter.im/dask/dask
   :target: https://gitter.im/dask/dask?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |Circle| image:: https://img.shields.io/circleci/project/github/dask/dask-mpi/master.svg?style=for-the-badge&logo=circleci
    :target: https://circleci.com/gh/dask/dask-mpi/tree/master

.. |Codecov| image:: https://img.shields.io/codecov/c/github/dask/dask-mpi.svg?style=for-the-badge
    :target: https://codecov.io/gh/dask/dask-mpi

.. |Docs| image:: https://readthedocs.org/projects/dask-mpi/badge/?version=latest&style=for-the-badge
    :target: https://mpi.dask.org/en/latest/?badge=latest
    :alt: Documentation Status

.. |PyPI| image:: https://img.shields.io/pypi/v/dask-mpi.svg?style=for-the-badge
    :target: https://pypi.org/project/dask-mpi/
    :alt: Python Package Index

.. |Conda| image:: https://img.shields.io/conda/vn/conda-forge/dask-mpi.svg?style=for-the-badge
    :target: https://anaconda.org/conda-forge/dask-mpi
    :alt: Python Package Index
